


%   This function produces the BIC for the fixed transition function model
%   BIC = -2 * log(likelihood) + k * log(n)
%   k == number of parameters
%   n == number of observations

function [bic] = fastar_bic_RDH(draw,priors,data)
%   Compute the likelihood
%   Compute the residual for the VAR series
resid = zeros(priors.N+1,priors.T);
for t = 1:priors.T   
    Xst = 1;
    for p = 1:priors.P
        Xst = [Xst data.Y_minus(:,t,p)' draw.F_minus(:,t,p)'];
    end,
    for n = 1:priors.N
        resid(n,t) = data.Y(n,t) - draw.A1(n,:) * Xst';
        resid(n,t) = resid(n,t) - draw.phi_val(1,t) * draw.A2(n,:) * Xst';
    end,
    for n = 1 + priors.N:1 + priors.N
        resid(n,t) = draw.F(n-priors.N,t) - draw.A1(n,:) * Xst';
        resid(n,t) = resid(n,t) - draw.phi_val(1,t) * draw.A2(n,:) * Xst';
    end,
end,

log_likelihood = 0;
for t = 1 : priors.T
    omega_reduced = draw.OMEGA(1:priors.N,1:priors.N,t);
    inv_omega=inv(draw.OMEGA(:,:,t)); 
    inv_omega_reduced = inv_omega(1:priors.N,1:priors.N);
    term1 = - (priors.N/2) * log(2*pi);
    term2 = - 0.5 * log(det(omega_reduced));
    term3 = - resid(1:priors.N,t)' * inv_omega_reduced * resid(1:priors.N,t);
    log_likelihood = log_likelihood + term1 + term2 + term3;
end,

%   Compute the residuals for the factor measurement series
% for n_x = 1:priors.N_x
%     dev = zeros(priors.T,1);
%     for t = priors.P + priors.start_x(n_x,1):priors.T
%         Yt = data.X(n_x,t);
%         Xst = draw.F(:,t);
%         dev(t,1) = Yt - draw.beta(n_x,:) * Xst;
%     end,
%     term1 = - 0.5 * log(2*pi);
%     term2 = - 0.5 * log(draw.sig(n_x,1));
%     term3 = - dev' * inv(draw.sig(n_x,1)) * dev;
% end,

bic = -2 * log_likelihood + 2*(priors.N+(priors.N^2)*priors.P) * log(priors.T);