%   *************************************************************************************************************************
%   fastar15_RDH
%   THIS VERSION 09.24.2013
%   *************************************************************************************************************************
%   This function estimates the factor STAR model
%   y_t = phi(F_tm1) * A(L) y_tm1 + (1 - phi(F_tm1)) * B(L) y_tm1 + e_t

%   This version has:
%       1. regime-rependent variance-covariance matrices
%       2. factor intercepts restricted to zero
%       3. unbalanced measurement equation series
%   For the unbalanced panel, all of the X data will be the same dimension but will be populated by NaNs for values prior to
%   the start of the series.
%   *************************************************************************************************************************
clear;clc;close all
datanam = 'cooked_data_2017.xls';
[priors,draw,results,data] = fastar_priors_RDH_F(datanam);
inF=draw.F;
%   ******************************************************************
%   Iterate
%   ******************************************************************
for i = 1:priors.keep + priors.burn;
    disp(['Iteration ', num2str(i),' ; acc ',num2str(draw.acc/i)]);
    disp(['acc1 ',num2str(draw.acc1/i),' ; acc2 ',num2str(draw.acc2/i)]);
    %   ******************************************************************
    %   VAR coefficients
    %   ******************************************************************
    [r,R] = fastar_A_RDH_F(draw,priors,data);
    [draw.A1,draw.A2] = draw_A_RDH_F(r,R,priors);
    %   ******************************************************************
    %   Metropolis the coefficients in the logistic transition equation
    %   ******************************************************************
    [draw.gamma,draw.c,draw.phi_val,AA,acc] = fastar_GAMMA_RDH(draw,priors,data);
    draw.acc = draw.acc + acc;
    %   ******************************************************************
    %   Factors, Factor Loadings, Inclusion Indicators
    %   ******************************************************************
    [draw] = fastar_joint_draw_RDH(draw,priors,data);
    %   ***********************************************************************************
    %   Draw the factor candidate conditional on the the factor loading and the inclusion candidate
    [star] = fastar_F_GVS_3_RDH(draw,priors,data);
    draw.F_minus = star.F_minus;
    draw.F = star.F;
    draw.phi_val = star.phi_val;
    data.st = draw.F_minus(:,:,1);
    %   ******************************************************************
    %   Measurement Variances
    %   ******************************************************************
    for n_x = 1:priors.N_x
        [w,W] = fastar_SIG_RDH(draw,priors,data,n_x);
        draw.sig(n_x,:) = inv(wishrnd(W,w));
    end,
    %   ******************************************************************
    %   Variance-Covariance
    %   ******************************************************************
    [draw,acc1] = fastar_OMEGA_1_RDH(draw,priors,data);
    [draw,acc2] = fastar_OMEGA_2_RDH(draw,priors,data);
    draw.acc1 = draw.acc1 + acc1;
    draw.acc2 = draw.acc2 + acc2;
    %   ******************************************************************
    %   Storage
    %   ******************************************************************
    if i > priors.burn;
        i_star = i - priors.burn;
        results.A1(:,:,i_star) = draw.A1;
        results.A2(:,:,i_star) = draw.A2;
        results.OMEGA1(:,:,i_star) = draw.OMEGA1;
        results.OMEGA2(:,:,i_star) = draw.OMEGA2;
        results.gamma(:,i_star) = draw.gamma;
        results.c(:,i_star) = draw.c;
        results.phi_val(:,i_star) = draw.phi_val;
        results.F(:,:,i_star) = draw.F;
        results.lam(:,i_star) = draw.lam;
        results.sig(:,i_star) = draw.sig;
        results.beta(:,i_star) = draw.beta;
    end,
end,
meanz.A1 = mean(results.A1,3);
meanz.A2 = mean(results.A2,3);
meanz.omega1 = mean(results.OMEGA1,3);
meanz.omega2 = mean(results.OMEGA2,3);
meanz.gamma = mean(results.gamma,2);
meanz.c = mean(results.c,2);
meanz.phi_val = mean(results.phi_val,2);
meanz.F = mean(results.F,3);
meanz.lam = mean(results.lam,2);
meanz.sig = mean(results.sig,2);
meanz.beta = mean(results.beta,2);

%forecasts

for i=1:priors.nf
    ni=priors.Hfc(i);
    draw.A1=results.A1(:,:,ni); 
    draw.A2=results.A2(:,:,ni);
    draw.OMEGA1=results.OMEGA1(:,:,ni); 
    draw.OMEGA2=results.OMEGA2(:,:,ni); 
    draw.gamma=results.gamma(:,ni); 
    draw.c=results.c(:,ni);
    draw.phi_val=results.phi_val(:,ni);
    draw.lam=results.lam(:,ni);
    draw.sig=results.sig(:,ni);
    draw.beta=results.beta(:,ni);
    draw.F=results.F(:,:,ni);  
    draw.sc=std(draw.F(:,5:end,1),1,2); 
    draw.F_minus = normrnd(priors.f,sqrt(priors.F),1,priors.T+priors.P,priors.P);
    draw.F_minus(:,1+1:priors.T+1,1) = draw.F;
    [results.yf(:,:,i),results.tf(:,:,i)]=fore(data, priors,draw, 200);
end,
    
meanz.yf=mean(results.yf,3); 
meanz.tf=mean(results.tf,3); 

