
function [draw,acc] = fastar_OMEGA_1_RDH(draw,priors,data)
%   **************************************************************
%   Compute the hyperparameters for the proposal density
%   **************************************************************
f = draw.F_minus < draw.c;
T1 = sum(f);
nu1 = T1 + priors.rho;
%   ********************
sumYmXb1 = 0;
star.resid = zeros(priors.N+1,priors.T);
for t = 1:priors.T
    Xst = 1;
    for p = 1:priors.P
        Xst = [Xst data.Y_minus(:,t,p)' draw.F_minus(:,t,p)'];
    end,
    for n = 1:priors.N
        star.resid(n,t) = data.Y(n,t) - draw.A1(n,:) * Xst';
        star.resid(n,t) = star.resid(n,t) - draw.phi_val(1,t) * draw.A2(n,:) * Xst';
    end,
    for n = 1 + priors.N:1 + priors.N
        star.resid(n,t) = draw.F(n-priors.N,t) - draw.A1(n,:) * Xst';
        star.resid(n,t) = star.resid(n,t) - draw.phi_val(1,t) * draw.A2(n,:) * Xst';
    end,
    sumYmXb1 = sumYmXb1 + (1 - draw.phi_val(1,t)) * star.resid(:,t) * star.resid(:,t)';
end,
R1 = inv(inv(priors.R) + sumYmXb1);
%   *************************************************************
%   Draw the candidate
%   **************************************************************
%   Square the precision matrix
x = chol(R1)' * chol(R1);
star.inv_OMEGA1 = wishrnd(x * priors.del_x1,nu1 / priors.del_x1);
star.OMEGA1 = inv(star.inv_OMEGA1);
% disp(star.OMEGA1)
% disp(draw.OMEGA1)
%   *************************************************************
%   Accept or rejct the candidate
%   *************************************************************
%   Compute the ratio of the likelihoods
star.OMEGA = zeros(priors.N+1,priors.N+1,priors.T);
star.like = 0;
for t = 1 : priors.T
    %   Compute the sequence of OMEGAs based on the two
%     star.OMEGA(:,:,t) = star.OMEGA1 * draw.phi_val(:,t) + (1 - draw.phi_val(:,t)) * draw.OMEGA2;
    star.OMEGA(:,:,t) = star.OMEGA1 *(1- draw.phi_val(:,t)) + (draw.phi_val(:,t)) * draw.OMEGA2;
    star.like = - logdet(star.OMEGA(:,:,t)) / 2;
    star.like = star.like - star.resid(:,t)' * inv(star.OMEGA(:,:,t)) * star.resid(:,t);
end,
draw.OMEGA = zeros(priors.N+1,priors.N+1,priors.T);
draw.like = 0;
for t = 1 : priors.T
    %   Compute the sequence of OMEGAs based on the two
%     draw.OMEGA(:,:,t) = draw.OMEGA1 * draw.phi_val(:,t) + (1 - draw.phi_val(:,t)) * draw.OMEGA2;
    draw.OMEGA(:,:,t) = draw.OMEGA1 * (1-draw.phi_val(:,t)) + ( draw.phi_val(:,t)) * draw.OMEGA2;
    draw.like = - logdet(draw.OMEGA(:,:,t)) / 2;
    draw.like = draw.like - draw.resid(:,t)' * inv(draw.OMEGA(:,:,t)) * draw.resid(:,t);
end,
%   Compute the ratio of the priors
star.prior = log_wish_pdf(inv(star.OMEGA1), priors.rho, inv(priors.R));

%   Compute the ratio of the move probabilities
[draw.move] = log_wish_pdf(draw.OMEGA1, nu1 / priors.del_x1, x * priors.del_x1);
[star.move] = log_wish_pdf(star.OMEGA1, nu1 / priors.del_x1, x * priors.del_x1);

top = [star.like, star.prior draw.move];
bot = [draw.like, draw.prior1 star.move];
a = min([1,exp(sum(top) - sum(bot))]);
u = rand;
if u < a
    draw.OMEGA1 = star.OMEGA1;
    %draw.inv_OMEGA1 = star.inv_OMEGA1;
    draw.OMEGA = star.OMEGA;
    acc = 1;
else
    acc = 0;
end,

%error('stop')
