%   ***********************************************************************************
%   This function jointly draws the factors, factor loadings and inclusion indicators
%   ***********************************************************************************
%   The draw is a joint MH draw. The steps are:
%   1. Draw the inclusion candidates
%   2. Draw the factor loading candidates conditional on the inclusion candidates and the past value of F
%   3. Draw the factor candidate conditional on the the factor loading and the inclusion candidate
%   4. Accept or reject the candidates
%   ***********************************************************************************
function [draw,acc] = fastar_joint_draw_RDH(draw,priors,data)
%   ***********************************************************************************
%   Draw the inclusion candidates
star.lam = draw.lam;
star.lam_star = unidrnd(priors.N_x);
star.lam(star.lam_star,1) = 1 - draw.lam(star.lam_star,1);
% star.lam(1)=1; %this will keep always the first variable in. Try to stop inverting the sign. 
%   ***********************************************************************************
%   Draw the factor loading candidates conditional on the inclusion candidates and the past value of F
bb_star = zeros(priors.N_x,1);
BB_star = ones(priors.N_x,1);
bb_draw = zeros(priors.N_x,1);
BB_draw = ones(priors.N_x,1);
% for n_x=1
%     if star.lam(n_x,1) == 0
%         star.beta(n_x,1) = 0;
%     else
%  [b,B] = fastar_LOAD_RDH(draw,priors,data,n_x);
%         bb_star(n_x,1) = b;
%         if b<0; 
%          bb_star(n_x,1)=-b;
%         end 
%         BB_star(n_x,1) = B;
%         star.beta(n_x,1) = bb_star(n_x,1) + chol(B,'lower') * normrnd(0,1,1,1);
%     end
% end        
for n_x = 1:priors.N_x
    if star.lam(n_x,1) == 0
        star.beta(n_x,1) = 0;
    else
        [b,B] = fastar_LOAD_RDH(draw,priors,data,n_x);
        bb_star(n_x,1) = b;
        BB_star(n_x,1) = B;
        star.beta(n_x,1) = b + chol(B,'lower') * normrnd(0,1,1,1);
    end,
end,
for n_x = 1:priors.N_x
    if draw.lam(n_x,1) == 0
    else
        [bb_draw(n_x,1),BB_draw(n_x,1)] = fastar_LOAD_RDH(draw,priors,data,n_x);
    end,
end,
%   Accept or reject the candidates
BBB_star = diag(BB_star);
top = sqrt(det(BBB_star)) * exp(0.5 * bb_star' * inv(BBB_star) * bb_star);
BBB_draw = diag(BB_draw);
bot = sqrt(det(BBB_draw)) * exp(0.5 * bb_draw' * inv(BBB_draw) * bb_draw);
if star.lam(star.lam_star,1) == 1
    top = top * priors.lam_on;
    bot = bot * (1 - priors.lam_on);
else
    top = top * (1 - priors.lam_on);
    bot = bot * priors.lam_on;
end,
AA = min([1,top/bot]);
u = rand(1);
if u <= AA;
    draw.beta = star.beta;
    draw.lam = star.lam;
    acc = 1;
else
    acc = 0;
end,